@@ -17,11 +17,10 @@ __title__ = 'projectZ.py'
 __author__ = 'Xsarz'
 __license__ = 'MIT'
 __copyright__ = 'Copyright 2023 Xsarz'
-__version__ = '1.1.3.1'
+__version__ = '1.1.6.1'
 
-def init():
-	__newest__ = loads(get("https://pypi.org/pypi/projectZ.py/json").text)["info"]["version"]
-	if __version__ != __newest__:
-		s('cls || clear')
-		print(fore.ORANGE_1, f'{__title__} made by {__author__}\nPlease update the library. Your version: {__version__}  A new version:{__newest__}', fore.WHITE)
-init()
\ No newline at end of file
+
+__newest__ = loads(get("https://pypi.org/pypi/projectZ.py/json").text)["info"]["version"]
+if __version__ != __newest__:
+	s('cls || clear')
+	print(fore.ORANGE_1, f'{__title__} made by {__author__}\nPlease update the library. Your version: {__version__}  A new version:{__newest__}', fore.WHITE)
\ No newline at end of file
