@@ -1,4 +1,5 @@
 from websocket import WebSocketApp, enableTrace
+from websocket import _exceptions as WSexceptions
 from .utils import exceptions
 from threading import Thread
 from time import sleep
@@ -13,12 +14,24 @@ class Socket:
 
 		self.client = client
 		self.active = False
+		self.online_loop_active = False
 		self.socket_thread = None
+		self.reconnectTime = 90
+		self.reconnect_thread = None
+		self.buffer = list()
 		enableTrace(sock_trace)
 
 
 	def resolve(self, ws, data):
 		data = loads(data)
+		try:
+			messageId = data['msg']['messageId']
+			if messageId in self.buffer:
+				return
+			self.buffer.append(messageId)
+			#I know, it looks like shit, but I haven't come up with another way yet (when the socket is rebooted, all messages that have already come come again)
+		except:
+			pass
 		self.on_all(data)
 		self.methods.get(data['t'])(data)
 
@@ -35,12 +48,14 @@ class Socket:
 			self.socket_thread = Thread(target=self.socket.run_forever)
 			self.socket_thread.start()
 			self.active = True
-			Thread(target=self.ping).start()
-			
+			if self.reconnect_thread is None:
+				self.reconnect_thread = Thread(target=self.reconnect)
+				self.reconnect_thread.start()
 			if self.debug:
 				print(f"[socket][start] Socket Started")
 		except Exception as e:
-			print(e)
+			if self.debug:
+				print(f"[socket][start] Error while starting Socket : {e}")
 
 	def disconnect(self):
 		if self.debug:
@@ -54,14 +69,30 @@ class Socket:
 				print(f"[socket][close] Error while closing Socket : {e}")
 		return
 
+	def reconnect(self):
+		while True:
+			sleep(self.reconnectTime)
+			if self.active:
+				if self.debug is True:
+					print(f"[socket][reconnect_handler] Reconnecting Socket")
+				self.disconnect()
+				self.connect()
 
-	def ping(self):
+	def online_loop(self):
 		sleep(1.5)
-		while self.active:
-			self.send()
+		while self.online_loop_active:
+			try:
+				self.send()
+			except WSexceptions.WebSocketConnectionClosedException:
+				sleep(1.5)
+				continue
+			except Exception as e:
+				if self.debug:
+					print('[socket][_online_loop][error] ', e)
 			sleep(3)
 
 
+
 	def send(self, t: int = 8, data = None, threadId: int = None):
 		
 		if not self.socket_thread:
@@ -139,7 +170,7 @@ class CallBacks:
 	def call(self, type, data):
 		if type in self.handlers:
 			for handler in self.handlers[type]:
-				handler(objects.Event(data).Event)
+				handler(objects.Event(data))
 
 
 	def on_text_message(self, data): self.call(type='on_text_message', data=data)
